==> linux-5.4.284.tar.gz: linux-5.4.284/drivers/gpu/drm/amd/include/asic_reg/umc/umc_6_1_1_offset.h <==
/*
 * Copyright (C) 2019  Advanced Micro Devices, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _umc_6_1_1_OFFSET_HEADER
#define _umc_6_1_1_OFFSET_HEADER

#define mmUMCCH0_0_EccErrCntSel                                                                        0x0360
#define mmUMCCH0_0_EccErrCntSel_BASE_IDX                                                               0
#define mmUMCCH0_0_EccErrCnt                                                                           0x0361
#define mmUMCCH0_0_EccErrCnt_BASE_IDX                                                                  0
#define mmMCA_UMC_UMC0_MCUMC_STATUST0                                                                  0x03c2
#define mmMCA_UMC_UMC0_MCUMC_STATUST0_BASE_IDX                                                         0

#endif

==> linux-5.10.44.tar.gz: linux-5.10.44/drivers/gpu/drm/amd/include/asic_reg/umc/umc_8_7_0_offset.h <==
/*
 * Copyright (C) 2020  Advanced Micro Devices, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _umc_8_7_0_OFFSET_HEADER
#define _umc_8_7_0_OFFSET_HEADER

#define mmUMCCH0_0_GeccErrCntSel                                  0x0328
#define mmUMCCH0_0_GeccErrCntSel_BASE_IDX                         0
#define mmUMCCH0_0_GeccErrCnt                                     0x0329
#define mmUMCCH0_0_GeccErrCnt_BASE_IDX                            0
#define mmMCA_UMC_UMC0_MCUMC_STATUST0                             0x03c2
#define mmMCA_UMC_UMC0_MCUMC_STATUST0_BASE_IDX                    0
#define mmMCA_UMC_UMC0_MCUMC_ADDRT0                               0x03c4
#define mmMCA_UMC_UMC0_MCUMC_ADDRT0_BASE_IDX      		  0

#endif
